#ifndef NT2_INCLUDE_FUNCTIONS_DIVS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIVS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/divs.hpp>

#endif
